summaryrefslogtreecommitdiffstats
path: root/ppapi/c
diff options
context:
space:
mode:
authordschuff@chromium.org <dschuff@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-09-04 21:34:25 +0000
committerdschuff@chromium.org <dschuff@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-09-04 21:34:25 +0000
commita675c011e16db84fc2022a34d25a8c03bf76cdcd (patch)
tree1ad1e0006ad26f651a85961570ccc8f13ab7746b /ppapi/c
parent50c79657b611ac92cbe54dc94ecb2f60d802688b (diff)
downloadchromium_src-a675c011e16db84fc2022a34d25a8c03bf76cdcd.zip
chromium_src-a675c011e16db84fc2022a34d25a8c03bf76cdcd.tar.gz
chromium_src-a675c011e16db84fc2022a34d25a8c03bf76cdcd.tar.bz2
Handle cache-control:no-store header in PNaCl translation cache
Pexe files with the cache-control:no-store header should not be cached. Add a field to the PnaclCacheInfo struct, plumb the value all the way from the plugin to the browser, and treat it basically the same way we currently treat incognito translations (since we currently don't have an off-the-record cache for those). R=jvoung@chromium.org BUG=none, noticed this was missing when doing cleanup Review URL: https://chromiumcodereview.appspot.com/23458015 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@221275 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ppapi/c')
-rw-r--r--ppapi/c/private/ppb_nacl_private.h28
1 files changed, 15 insertions, 13 deletions
diff --git a/ppapi/c/private/ppb_nacl_private.h b/ppapi/c/private/ppb_nacl_private.h
index 772998b..6441efd 100644
--- a/ppapi/c/private/ppb_nacl_private.h
+++ b/ppapi/c/private/ppb_nacl_private.h
@@ -3,7 +3,7 @@
* found in the LICENSE file.
*/
-/* From private/ppb_nacl_private.idl modified Mon Aug 19 14:06:38 2013. */
+/* From private/ppb_nacl_private.idl modified Thu Aug 29 17:42:12 2013. */
#ifndef PPAPI_C_PRIVATE_PPB_NACL_PRIVATE_H_
#define PPAPI_C_PRIVATE_PPB_NACL_PRIVATE_H_
@@ -122,18 +122,19 @@ struct PPB_NaCl_Private_1_0 {
* returns a posix handle to that temporary file.
*/
PP_FileHandle (*CreateTemporaryFile)(PP_Instance instance);
/* Create a temporary file, which will be deleted by the time the last
* handle is closed (or earlier on POSIX systems), to use for the nexe
* with the cache information given by |pexe_url|, |abi_version|, |opt_level|,
* |last_modified|, and |etag|. If the nexe is already present
* in the cache, |is_hit| is set to PP_TRUE and the contents of the nexe
* will be copied into the temporary file. Otherwise |is_hit| is set to
* PP_FALSE and the temporary file will be writeable.
* Currently the implementation is a stub, which always sets is_hit to false
* and calls the implementation of CreateTemporaryFile. In a subsequent CL
* it will call into the browser which will remember the association between
* the cache key and the fd, and copy the nexe into the cache after the
* translation finishes.
*/
int32_t (*GetNexeFd)(PP_Instance instance,
const char* pexe_url,
@@ -141,6 +142,7 @@ struct PPB_NaCl_Private_1_0 {
uint32_t opt_level,
const char* last_modified,
const char* etag,
+ PP_Bool has_no_store_header,
PP_Bool* is_hit,
PP_FileHandle* nexe_handle,
struct PP_CompletionCallback callback);
@@ -122,18 +122,19 @@ struct PPB_NaCl_Private_1_0 {
*/
PP_FileHandle (*CreateTemporaryFile)(PP_Instance instance);
- /* Create a temporary file, which will be deleted by the time the last
- * handle is closed (or earlier on POSIX systems), to use for the nexe
- * with the cache information given by |pexe_url|, |abi_version|, |opt_level|,
- * |last_modified|, and |etag|. If the nexe is already present
- * in the cache, |is_hit| is set to PP_TRUE and the contents of the nexe
- * will be copied into the temporary file. Otherwise |is_hit| is set to
- * PP_FALSE and the temporary file will be writeable.
- * Currently the implementation is a stub, which always sets is_hit to false
- * and calls the implementation of CreateTemporaryFile. In a subsequent CL
- * it will call into the browser which will remember the association between
- * the cache key and the fd, and copy the nexe into the cache after the
- * translation finishes.
+ /* Create a temporary file, which will be deleted by the time the
+ * last handle is closed (or earlier on POSIX systems), to use for
+ * the nexe with the cache information given by |pexe_url|,
+ * |abi_version|, |opt_level|, |last_modified|, |etag|, and
+ * |has_no_store_header|. If the nexe is already present in the
+ * cache, |is_hit| is set to PP_TRUE and the contents of the nexe
+ * will be copied into the temporary file. Otherwise |is_hit| is set
+ * to PP_FALSE and the temporary file will be writeable. Currently
+ * the implementation is a stub, which always sets is_hit to false
+ * and calls the implementation of CreateTemporaryFile. In a
+ * subsequent CL it will call into the browser which will remember
+ * the association between the cache key and the fd, and copy the
+ * nexe into the cache after the translation finishes.
*/
int32_t (*GetNexeFd)(PP_Instance instance,